import glob
import sys
import os

current_script = os.path.abspath(__file__)
base_dir = os.path.dirname(current_script)
sys.path.insert(0, base_dir)

from parse_fwu import FWUFile, device_name


def sort_by_module_type(fwu: FWUFile):
    return fwu.module_type


fwu_files = []

for filename in glob.glob("fw_*_*.fwu"):
    fwu = FWUFile(filename)
    fwu_files.append(fwu)

if not fwu_files:
    print("Could not find any firmware files in working directory")
    exit(1)

readme = """# Firmware for RevPi exentsion modules

This package contains firmware files for RevPi I/O modules and for RevPi gateway modules.

## Modules

The following modules and versions are part of the firmware package:

| File | Module | Module Type | Firmware Version | SVN Tag | GIT Hash | Hardware Revision |
| ---- | ------ | ----------- | ---------------- | ------- | -------- | ----------------- |
"""

for fwu in sorted(fwu_files, key=sort_by_module_type):
    readme += (
        f"| `{fwu.filename}` "
        f"| {device_name(fwu.module_type)} "
        f"| {fwu.module_type} "
        f"| {fwu.version} "
        f"| {fwu.svn_tag} "
        f"| {fwu.git_hash} "
        f"| {fwu.hardware_revision}"
        "|\n"
    )

readme += "\n\n**Please note that this README file is auto-generated by the `tools/update-readme.py` script. More details can be found [here](tools/README.md)**"


with open("README.md", "w") as f:
    f.write(readme)
